## Final Answer

### Question

Work has ended for the following question:

```text
{question}
```

### Finish Reason

Our work has concluded for the following reason: 

```text
{finish_reason}
```

### Plan

Here is the completed plan that we developed and worked on to try to answer the question:

{plan}

### Results

Consider the work that we completed. 

- Based on the results, was our team able to answer the question?
  - If not, then unfortunately we cannot come to a definitive answer. Even if we *think* we know the answer, we need to be honest about the fact that our team didn't solve it.
  - If so, respond with that final answer.
- Sometimes we might create hypotheses that go beyond answering the original question. Don't worry about whether these are verified or not, just focus on verified results that are relevant to the original question.

#### Defining Success

- If we have any verified hypotheses, where the results of the experiments answer our original question, then we have succeeded!

#### Defining Failure

- If we have no verified hypotheses, then we have failed to answer the question.
- If we have some verified hypotheses, but they are not sufficient to answer the original question, then we have failed to answer the question.

> Failure is OK, let the user know that the results are incomplete, and summarize why we weren't able to come to a final answer.

### CRITICALLY IMPORTANT NOTES

- It's very important that you do not try to solve things yourself at the end. 
- If your team hasn't solved the problem, then it should be marked as "incomplete", even if you think you know the answer.
